<?php

if (!defined('NEXTENDLIBRARY')) {

    require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'library.php');

    nextendimport('nextend.wordpress.settings');


    class N1WordpressAssetInjector {

        private static $nextend_js = '';
        private static $nextend_css = '';

        public static function init() {			
			add_action('wp_footer', 'N1WordpressAssetInjector::finalizeCssJs' );
            add_action('wp_print_scripts', 'N1WordpressAssetInjector::injectCSSComment');

            if (is_admin()) {
                add_action('admin_init', 'N1WordpressAssetInjector::outputStart', 3000);
            }

            add_action('template_redirect', 'N1WordpressAssetInjector::outputStart', 10000);


            add_action('shutdown', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);
            add_action('pp_end_html', 'N1WordpressAssetInjector::closeOutputBuffers', -10000); // ProPhoto 6 theme
            add_action('headway_html_close', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);
            add_action('after_setup_theme', 'N1WordpressAssetInjector::after_setup_theme');
        }

        public static function after_setup_theme() {

            if (defined('GANTRY_VERSION') && version_compare(GANTRY_VERSION, '4.0.0', '>=') && version_compare(GANTRY_VERSION, '5.0.0', '<')) {
                remove_action('template_redirect', 'N1WordpressAssetInjector::outputStart', 10000);

                remove_action('shutdown', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);
                remove_action('pp_end_html', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);
                remove_action('headway_html_close', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);

                add_filter('gantry_before_render_output', 'N1WordpressAssetInjector::platformRenderEnd');
            }

            if (function_exists('tcb_custom_editable_content')) {
                remove_action('template_redirect', 'N1WordpressAssetInjector::outputStart', 10000);
                remove_action('shutdown', 'N1WordpressAssetInjector::closeOutputBuffers', -10000);
                add_action('template_redirect', 'N1WordpressAssetInjector::outputStart', 8);
                add_action('shutdown', 'N1WordpressAssetInjector::closeOutputBuffers', -8);
            }
        }

        public static function outputStart() {
            static $started = false;
            if (!$started) {
                $started = true;

                ob_start("N1WordpressAssetInjector::platformRenderEnd");
            }
        }

        public static function closeOutputBuffers() {
            self::finalizeCssJs();

            $handlers = ob_list_handlers();
            if (in_array('N1WordpressAssetInjector::platformRenderEnd', $handlers)) {
                for ($i = count($handlers) - 1; $i >= 0; $i--) {
                    ob_end_flush();
                    if ($handlers[$i] === 'N1WordpressAssetInjector::platformRenderEnd') {
                        break;
                    }
                }
            }
        }

        public static function platformRenderEnd($buffer) {

            if (self::$nextend_css != '' && strpos($buffer, '<!--n1css-->') !== false) {
                $buffer = str_replace('<!--n1css-->', self::$nextend_css, $buffer);

                self::$nextend_css = '';
            }

            if (self::$nextend_css != '' || self::$nextend_js != '') {
                $parts = preg_split('/<\/head[\s]*>/', $buffer, 2);

                return implode(self::$nextend_css . self::$nextend_js . '</head>', $parts);
            }

            return $buffer;
        }

        public static function finalizeCssJs() {
            static $finalized = false;
            if (!$finalized) {
                $finalized = true;

                if (class_exists('NextendCss', false) || class_exists('NextendJavascript', false)) {
                    ob_start();
                    do_action('nextend_css');
                    $css = NextendCss::getInstance();
                    $css->generateCSS();
                    echo '<script type="text/javascript">
(function (w, d, u) {
    if(w.njQuery === u){
        w.bindNextendQ = [];
    
        function pushToReady(x) {
            w.bindNextendQ.push([alias.handler,"ready", x]);
        }
        
        function pushToLoad(x) {
            w.bindNextendQ.push([alias.handler,"load", x]);
        }

        var alias = {
            handler: w,
            ready: pushToReady,
            load: pushToLoad
        }

        w.njQuery = function (handler) {
            alias.handler = handler;
            return alias;
        }
    }
})(window, document);
              </script>';
                    self::$nextend_css = ob_get_clean();

                    ob_start();
                    do_action('nextend_js');
                    $js = NextendJavascript::getInstance();
                    $js->generateJs();
                    self::$nextend_js = ob_get_clean();
                }

            }

            return true;
        }

        public static function injectCSSComment() {
            static $once;
            if (!$once) {
                echo "<!--n1css-->";
                $once = true;
            }
        }
    }

    N1WordpressAssetInjector::init();


    if (getNextend('logproblems')) {
        function nextend_error_checker() {
            global $nextend_wp_head, $nextend_wp_footer;
            if (class_exists('NextendCss', false) || class_exists('NextendJavascript', false)) {
                if ((!defined('DOING_AJAX') || !DOING_AJAX) && !is_admin()) {
                    if ($nextend_wp_head === false) {
                        nextend_add_error('missinghead');
                    } else if ($nextend_wp_footer === false) {
                        nextend_add_error('missingfooter');
                    }
                }
            }
        }

        function nextend_add_error($key) {
            static $nextenderror = null;
            if (!$nextenderror) {
                $nextenderror = get_option('nextend_error');
                if ($nextenderror === false) {
                    $nextenderror = array();
                }
            }
            if (!is_array($nextenderror[$key])) $nextenderror[$key] = array();
            $nextenderror[$key][] = $_SERVER["REQUEST_URI"];
            $nextenderror[$key]   = array_unique($nextenderror[$key]);
            update_option('nextend_error', $nextenderror);
        }

        register_shutdown_function('nextend_error_checker');
    }
}
